@@ -1,10 +1,11 @@
 package Telegram::BotKit::Keyboards;
-$Telegram::BotKit::Keyboards::VERSION = '0.02';
+$Telegram::BotKit::Keyboards::VERSION = '0.03';
 # ABSTRACT: Easy creation of keyboards for Telegram bots
 
 
-use JSON::MaybeXS;
 use common::sense;
+use JSON::MaybeXS;
+use Encode qw(decode);
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(create_one_time_keyboard create_inline_keyboard parse_reply_markup available_keys);
@@ -35,7 +36,8 @@ sub create_one_time_keyboard {
 		keyboard => \@keyboard,
 		one_time_keyboard => JSON::MaybeXS::JSON->true
 		);
-	return JSON::MaybeXS::encode_json(\%rpl_markup);
+	my $json = JSON::MaybeXS->new(utf8 => 1);
+	return decode('UTF-8', $json->encode(\%rpl_markup));
 }
 
 
@@ -57,7 +59,8 @@ sub create_inline_keyboard {
 	my %rpl_markup = (
 		inline_keyboard  => \@keyboard
 	);
-	return JSON::MaybeXS::encode_json(\%rpl_markup);
+	my $json = JSON::MaybeXS->new(utf8 => 1);
+	return decode('UTF-8', $json->encode(\%rpl_markup));
 }
 
 
@@ -117,7 +120,7 @@ Telegram::BotKit::Keyboards - Easy creation of keyboards for Telegram bots
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -204,7 +207,7 @@ Pavel Serikov <pavelsr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Pavel Serikov.
+This software is copyright (c) 2017 by Pavel Serikov.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
